@@ -32,7 +32,7 @@ class ProgressBar(Handler):
             "errors": 0,
             "warnings": 0,
             "ending": "Task Completed in" if task.percentage==1.0 else "Stopped at {:2.0f}%. Duration".format(task.percentage*100.0),
-            "duration":  datetime.time(second=int(dur))
+            "duration":  datetime.time(second=int(dur)%60, minute=(int(dur)%3600)/60, hours=int(dur)/3600)
         }
     
     max_counters=7
